]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Make sure we make a move at the end of the search when reaching
[stockfish] / src / tt.h
index 0b7ccbe8f948ecacc603b3d189c387c16d6b2008..5d0df726239cabb66cb13628ac3523e9fb676c9c 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -72,7 +72,21 @@ private:
   int16_t depth_;
 };
 
-/// The transposition table class.  This is basically just a huge array
+
+/// This is the number of TTEntry slots for each position
+const int ClusterSize = 5;
+
+/// Each group of ClusterSize number of TTEntry form a TTCluster
+/// that is indexed by a single position key. Cluster is padded
+/// to a cache line size so to guarantee always aligned accesses.
+
+struct TTCluster {
+  TTEntry data[ClusterSize];
+  char cache_line_padding[64 - sizeof(TTEntry[ClusterSize])];
+};
+
+
+/// The transposition table class. This is basically just a huge array
 /// containing TTEntry objects, and a few methods for writing new entries
 /// and reading new ones.
 
@@ -88,20 +102,20 @@ public:
   void prefetch(const Key posKey) const;
   void new_search();
   void insert_pv(const Position& pos, Move pv[]);
-  void extract_pv(const Position& pos, Move pv[]);
+  void extract_pv(const Position& pos, Move pv[], const int PLY_MAX);
   int full() const;
 
 private:
   inline TTEntry* first_entry(const Key posKey) const;
 
// Be sure 'writes' is at least one cacheline away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];
   unsigned writes; // heavy SMP read/write access here
   unsigned char pad_after[64];
 
   unsigned size;
-  TTEntry* entries;
+  TTCluster* entries;
   uint8_t generation;
 };
@@ -88,20 +102,20 @@ public:
   inline TTEntry* first_entry(const Key posKey) const;
 
-  // Be sure 'writes' is at least one cacheline away
+  // Be sure 'writes' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];